Ordinary Least Square
---------------------

.. currentmodule:: prismstudio

.. autosummary::
    :toctree: api/

        prismstudio.ols.sample_beta
        prismstudio.ols.sample_intercept
        prismstudio.ols.sample_residual
        prismstudio.ols.cross_sectional_beta
        prismstudio.ols.cross_sectional_intercept
        prismstudio.ols.cross_sectional_residual

